#
# spec file for package sdcv
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sdcv
Version:        0.5.5
Release:        1.1
Summary:        Console version of the Stardict program
License:        GPL-2.0-only
Group:          Productivity/Office/Dictionary
URL:            https://dushistov.github.io/sdcv/
Source:         https://github.com/Dushistov/sdcv/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.5
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  glib2-devel
BuildRequires:  readline-devel
BuildRequires:  zlib-devel

%description
Console version of the Stardict program.
It can employ all the dictionary files that belong to StarDict.
The word sdcv stands for StarDict under Console Version.

%prep
%setup -q

%build
%cmake
%make_build
# force recreation of the locale files
%make_build lang

%install
%cmake_install
%find_lang %{name} --with-man
%if 0%{?suse_version} < 1550
# Ukrainian translations used to be absent from filesystem package
echo '%%dir %{_mandir}/uk/' >> %{name}.lang
echo '%%dir %{_mandir}/uk/man1/' >> %{name}.lang
%endif

%files -f %{name}.lang
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%license LICENSE
%doc README.org NEWS AUTHORS

%changelog
* Sun Dec  3 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 0.5.5:
  * Avoid crashes when passing unknown dicts to the -u flag
  * Use off_t for stuff mainly assigned to a stat.st_size value
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.5.4:
  * Use binary search for synonyms
  * Various improvments in work with synonyms
  * Added --json (same as --json-output) to match man
  * Show all matched result
  * More robust parsing of ifo file
  * Prevent crash if file size of files not matched expecting one for .oft files
* Thu Feb 11 2021 antoine.belvire@opensuse.org
- Update to version 0.5.3:
  * Use single quotes around JSON data to reduce need for escaping
  * Store integer magic in cache file
  * Added $SDCV_HISTFILE to set history file
  * return exit code 2 if search term not found
  * Comply with the XDG Base Directory Specification
- Update cmake minimum build requirement to 3.5.
- Run spec-cleaner.
* Tue Sep  5 2017 idonmez@suse.com
- Update to version 0.5.2
  * Synonyms index support (.syn files) by Peter
  * Add support of json output by Peter (--json-output)
  * Add -e for exact searches (no fuzzy matches) by Peter
  * Fix FSF address in license by Tomáš Čech
* Wed Jul 26 2017 sleep_walker@opensuse.org
- bump to 0.5.1
* Thu May  5 2016 sleep_walker@opensuse.org
- spec-file cleanup
- fix download URL
* Tue Aug 12 2014 mcihar@suse.cz
- now builds using cmake
- spec file cleanup
- update to 0.5.0~beta2
  - all patches integrated upstream
* Mon May  9 2011 mcihar@suse.cz
- add bugfix patches from Debian to fix build
* Sat Jun 20 2009 PVince81@yahoo.fr
- Fixed french translation patch.
* Fri Jun 19 2009 PVince81@yahoo.fr
- Fixed language files searching.
* Mon Jun 15 2009 PVince81@yahoo.fr
- Added french translation
* Mon Jun 15 2009 PVince81@yahoo.fr
- Initial version
